You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2023/11/02 16:41:31 UTC

(commons-compress) 01/03: Javadoc

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-compress.git

commit adad930eac32ff444796a3bb2c3f22c2f109a94a
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Thu Nov 2 12:29:15 2023 -0400

    Javadoc
---
 .../compress/archivers/ArchiveStreamProvider.java  | 74 ++++++++--------------
 1 file changed, 27 insertions(+), 47 deletions(-)

diff --git a/src/main/java/org/apache/commons/compress/archivers/ArchiveStreamProvider.java b/src/main/java/org/apache/commons/compress/archivers/ArchiveStreamProvider.java
index eb1862c9..16ef4d2c 100644
--- a/src/main/java/org/apache/commons/compress/archivers/ArchiveStreamProvider.java
+++ b/src/main/java/org/apache/commons/compress/archivers/ArchiveStreamProvider.java
@@ -31,61 +31,41 @@ import java.util.Set;
 public interface ArchiveStreamProvider {
 
     /**
-     * Creates an archive input stream from an archiver name and an input
-     * stream.
+     * Creates an archive input stream from an archiver name and an input stream.
      *
      * @param name
      *            the archive name, i.e.
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ARJ},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#DUMP}
      *            or
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#SEVEN_Z}
      * @param in
      *            the input stream
      * @param encoding
      *            encoding name or null for the default
      * @return the archive input stream
      * @throws ArchiveException
      *             if the archiver name is not known
      * @throws StreamingNotSupportedException
      *             if the format cannot be read from a stream
      * @throws IllegalArgumentException
      *             if the archiver name or stream is null
      */
-    ArchiveInputStream createArchiveInputStream(final String name, final InputStream in, final String encoding)
-            throws ArchiveException;
+    ArchiveInputStream createArchiveInputStream(final String archiverName, final InputStream inputStream, final String encoding) throws ArchiveException;
 
     /**
-     * Creates an archive output stream from an archiver name and an output
-     * stream.
+     * Creates an archive output stream from an archiver name and an output stream.
      *
      * @param name
      *            the archive name, i.e.
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR}
      *            or
      *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO}
      * @param out
      *            the output stream
      * @param encoding
      *            encoding name or null for the default
      * @return the archive output stream
      * @throws ArchiveException
      *             if the archiver name is not known
      * @throws StreamingNotSupportedException
      *             if the format cannot be written to a stream
      * @throws IllegalArgumentException
      *             if the archiver name or stream is null
      */
-    ArchiveOutputStream createArchiveOutputStream(final String name, final OutputStream out, final String encoding)
-            throws ArchiveException;
+    ArchiveOutputStream createArchiveOutputStream(final String archiverName, final OutputStream outputStream, final String encoding) throws ArchiveException;
 
     /**
      * Gets all the input stream archive names for this provider
@@ -31,61 +31,41 @@ import java.util.Set;
      *
-     * @param name
-     *            the archive name, i.e.
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ARJ},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#DUMP}
-     *            or
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#SEVEN_Z}
-     * @param in
-     *            the input stream
-     * @param encoding
-     *            encoding name or null for the default
+     * @param archiverName the archiver name, i.e. {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ARJ},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#DUMP} or
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#SEVEN_Z}
+     * @param inputStream  the input stream
+     * @param encoding     encoding name or null for the default
      * @return the archive input stream
@@ -31,61 +31,41 @@ import java.util.Set;
      * @return the archive input stream
-     * @throws ArchiveException
-     *             if the archiver name is not known
-     * @throws StreamingNotSupportedException
-     *             if the format cannot be read from a stream
-     * @throws IllegalArgumentException
-     *             if the archiver name or stream is null
+     * @throws ArchiveException               if the archiver name is not known
+     * @throws StreamingNotSupportedException if the format cannot be read from a stream
+     * @throws IllegalArgumentException       if the archiver name or stream is null
      */
@@ -31,61 +31,41 @@ import java.util.Set;
      *
-     * @param name
-     *            the archive name, i.e.
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR}
-     *            or
-     *            {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO}
-     * @param out
-     *            the output stream
-     * @param encoding
-     *            encoding name or null for the default
+     * @param archiverName the archiver name, i.e. {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#AR},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#ZIP},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#TAR},
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#JAR} or
+     *                     {@value org.apache.commons.compress.archivers.ArchiveStreamFactory#CPIO}
+     * @param outputStream the output stream
+     * @param encoding     encoding name or null for the default
      * @return the archive output stream
@@ -31,61 +31,41 @@ import java.util.Set;
      * @return the archive output stream
-     * @throws ArchiveException
-     *             if the archiver name is not known
-     * @throws StreamingNotSupportedException
-     *             if the format cannot be written to a stream
-     * @throws IllegalArgumentException
-     *             if the archiver name or stream is null
+     * @throws ArchiveException               if the archiver name is not known
+     * @throws StreamingNotSupportedException if the format cannot be written to a stream
+     * @throws IllegalArgumentException       if the archiver name or stream is null
      */